#!/bin/bash
#
# buildArtDaq.sh <e2|e2:nompi|nu:e2:nompi> <opt|debug|prof>

basequal=${1}
extraqual=${2}

pkgver=v0_02_08

# check to see if qualifier is set
if [ -z ${basequal} ]
then
   echo "ERROR: please define the qualifier"
   echo "USAGE: buildArt.sh <e2|e2:nompi|nu:e2:nompi> <opt|debug|prof>"
   exit 1
fi

if [ "${extraqual}" = "opt" ]
then
    extra_opt="-o ${basequal}"
elif [ "${extraqual}" = "debug" ]
then
    extra_opt="-d ${basequal}"
elif [ "${extraqual}" = "prof" ]
then
    extra_opt="-p ${basequal}"
else
   echo "ERROR: please define the extra qualifier"
   echo "USAGE: buildArt.sh <e2|e2:nompi|nu:e2:nompi> <opt|debug|prof>"
   exit 1
fi
fullqual=${basequal}:${extraqual}
xqual=`echo ${basequal} | sed -e s%:%-%g`
qualdir=${xqual}-${extraqual}

echo "building for ${fullqual}"

source ${PRODUCTS}/setup
flvr=`ups flavor`
OS=`uname`

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

cetdir=${PRODUCTS}/artdaq/${pkgver}/cet
builddir=${PRODUCTS}/artdaq/${pkgver}/build-${flvr}/artdaq-${qualdir}
echo "building in ${builddir}"

echo "build artdaq ${pkgver} -q ${fullqual}"
if [ -d ${builddir} ]
then
   rm -rf ${builddir} 
fi
mkdir -p ${builddir}
if [ ! -d ${builddir} ]
then
   echo "ERROR: failed to create ${builddir}"
   exit 1
fi
cd ${builddir}

source ${cetdir}/artdaq/ups/setup_for_development ${extra_opt}

gccver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.7.1" ]
then
  echo " OK - gcc version is ${gccver}"
else
  echo "ERROR: wrong gcc version ${gccver}"
  exit 1
fi

set -x

cmake -DCMAKE_INSTALL_PREFIX=${PRODUCTS} -DCMAKE_BUILD_TYPE=$CETPKG_TYPE $CETPKG_SOURCE
make -j4
make ARGS=-j4 test
make install

set +x 

# this should not complain
setup artdaq ${pkgver} -q ${fullqual}
echo "artdaqdaq is installed at ${ARTDAQ_FQ_DIR}"

exit 0

